* PROJECT:
* Jan Eeckhout, Roberto Pinheiro, Kurt Schmidheiny
* "Spatial Sorting"
* Forthcoming 2014 in the Journal of Political Economy
*
* FILE: 
* section1.do
*
* DESCRIPTION:
* produce figure 1 in section 1
*
* VERSION: 
* Jan-13-2014

clear all

* open skill data from CPS
use finaldata/skillcps.dta

* define city groups
generate group = .
replace group = 1 if pop2009<=1000000 & pop2009>100000 & ~missing(pop2009)
replace group = 2 if pop2009>2500000 & ~missing(pop2009)
label define group 1 "pop < 1m" 2 "pop > 2.5m"
generate group1 = (group==1) if ~missing(group)
generate group2 = (group==2) if ~missing(group)

* ------------------------------
*  Figure 1 left
* ------------------------------

* use same sample for wage and skill
* drops data for individuals outside identified cbsa and cbsa without price data
replace lwage = . if missing(lutility1) 

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lwage if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lwage if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lwage group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lwage if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lwage if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lwage if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(6(1)8) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(6(1)8) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("log wage") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.5) ysize(4.3) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);

#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_1_left.pdf", replace
graph export "results/figure_1_left.eps", replace

* ------------------------------
*  Figure 1 right
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility)") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) // add 0.15 to ysize() per line in note()
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_1_right.pdf", replace
graph export "results/figure_1_right.eps", replace
