* PROJECT:
* Jan Eeckhout, Roberto Pinheiro, Kurt Schmidheiny
* "Spatial Sorting"
* Forthcoming 2014 in the Journal of Political Economy
*
* FILE: 
* section6.do
*
* DESCRIPTION:
* produce figures 4, 5, 6, 7, 9, 10 in section 6
* and figure 14 in Appendix B
*
* VERSION: 
* Jan-13-2014

clear all

* ------------------------------
* Figure 4
* ------------------------------

* open skill data from CPS
use finaldata/skillcps.dta, clear

* sample,  keep only observations
* - identified CBSA 
* - with assigned CBSA housing price
* - cbsa with population > 100000
keep if ~missing(cbsa) & ~missing(rentindexcbsa) & (pop2009>=100000 & ~missing(pop2009))

* define city groups

generate group = .
replace group = 1 if pop2009<=1000000 & pop2009>100000 & ~missing(pop2009)
replace group = 2 if pop2009>2500000 & ~missing(pop2009)
label define group 1 "pop < 1m" 2 "pop > 2.5m"
generate group1 = (group==1) if ~missing(group)
generate group2 = (group==2) if ~missing(group)

* ------------------------------
* Figure 4 left
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility2 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility2 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility2 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility2 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility2 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility2 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility)") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_4_left.pdf", replace
graph export "results/figure_4_left.eps", replace

* ------------------------------------------------------------
* Figure 4 right
* ------------------------------------------------------------

* estimate selective quantile regressions for footer of figure
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	qreg lutility2 lpop2009 [aw=earnwt], q(`quant')
	estimates store skill_q`quantpct'
	predict lutility_q`quantpct' if e(sample), xb
	local slope`quantpct' = string(_b[lpop2009],"%9.3f")
	local se`quantpct' = string(_se[lpop2009],"%9.3f")
	local p`quantpct' = string(ttail(e(df_r), abs(_b[lpop2009]/_se[lpop2009])),"%9.1f")
	if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.005 {
		local star`quantpct' = "***"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.025 {
		local star`quantpct' = "**"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.05 {
		local star`quantpct' = "*"
	}
	else {
		local star`quantpct' = ""
	}

}

* plot all quantiles
qreg lutility2 lpop2009 [aw=earnwt]
grqreg lutility2 lpop2009 [aw=earnwt], ci save(temp/figure_4_right.dta)
use temp/figure_4_right.dta, clear
#delimit ;
twoway 
	rarea lpop2009_cihi lpop2009_cilo qtile, lpattern(none) color(gs14) legend(label(1 "95% confidence bounds")) 
	||
	line lpop2009 qtile, lpattern(solid) lcolor(black) legend(label(2 "slope coefficient")) 
	, xtitle("skill quantile") ytitle("slope of log population") 
	scheme(s1color) legend(region(lstyle(none))) legend(order(2 1)) legend(rows(1))
	yline(0, lpattern(solid))
	xsize(5.50) ysize(4.3) scale(1)
	note(
		"10th percentile: slope = `slope10'`star10' (`se10')" 
		"90th percentile: slope = `slope90'`star90' (`se90')" 
	);
#delimit cr

* save graph
graph export "results/figure_4_right.pdf", replace
graph export "results/figure_4_right.eps", replace

* ------------------------------
* Figure 5
* ------------------------------

clear all

* open skill data from ACS
use finaldata/skillacs.dta

* sample,  keep only observations
* - identified CBSA 
* - with assigned CBSA housing price
* - cbsa with population > 100000
keep if ~missing(cbsa) & ~missing(rentindexcbsa) & (pop2009>=100000 & ~missing(pop2009))

* define city groups
generate group = .
replace group = 1 if pop2009<=1000000 & pop2009>100000 & ~missing(pop2009)
replace group = 2 if pop2009>2500000 & ~missing(pop2009)
label define group 1 "pop < 1m" 2 "pop > 2.5m"
generate group1 = (group==1) if ~missing(group)
generate group2 = (group==2) if ~missing(group)

* number of workers and CBSA in sample
sum wage
codebook cbsa

* ------------------------------
* Figure 5 left
* ------------------------------

* already same observations for wage and skill
sum wage if missing(utility1) 

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lwage if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lwage if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lwage group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lwage if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lwage if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lwage if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("log wage") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_5_left.pdf", replace
graph export "results/figure_5_left.eps", replace

* ------------------------------
* Figure 5 right
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility)") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_5_right.pdf", replace
graph export "results/figure_5_right.eps", replace

* ------------------------------
* Figure 6 left
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility3 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility3 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility3 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility3 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility3 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility3 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility)") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_6_left.pdf", replace
graph export "results/figure_6_left.eps", replace

* ------------------------------------------------------------
* Figure 6 right
* ------------------------------------------------------------


* keep only observations from cbsa with more than 0.1 Mio
keep if (pop2009>=100000 & ~missing(pop2009))

* estimate selective quantile regressions for footer of figure
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	qreg lutility3 lpop2009 [aw=earnwt], q(`quant')
	estimates store skill_q`quantpct'
	predict lutility_q`quantpct' if e(sample), xb
	local slope`quantpct' = string(_b[lpop2009],"%9.3f")
	local se`quantpct' = string(_se[lpop2009],"%9.3f")
	local p`quantpct' = string(ttail(e(df_r), abs(_b[lpop2009]/_se[lpop2009])),"%9.1f")
	if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.005 {
		local star`quantpct' = "***"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.025 {
		local star`quantpct' = "**"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.05 {
		local star`quantpct' = "*"
	}
	else {
		local star`quantpct' = ""
	}

}

* plot all quantiles
qreg lutility3 lpop2009 [aw=earnwt]
grqreg lutility3 lpop2009 [aw=earnwt], ci save(temp/figure_6_right.dta)
use temp/figure_6_right.dta, clear
#delimit ;
twoway 
	rarea lpop2009_cihi lpop2009_cilo qtile, lpattern(none) color(gs14) legend(label(1 "95% confidence bounds")) 
	||
	line lpop2009 qtile, lpattern(solid) lcolor(black) legend(label(2 "slope coefficient")) 
	, xtitle("skill quantile") ytitle("slope of log population") 
	scheme(s1color) legend(region(lstyle(none))) legend(order(2 1)) legend(rows(1))
	yline(0, lpattern(solid))

	xsize(5.50) ysize(4.3) scale(1)
	note(
		"10th percentile: slope = `slope10'`star10' (`se10')" 
		"90th percentile: slope = `slope90'`star90' (`se90')" 
	);
#delimit cr

* save graph
graph export "results/figure_6_right.pdf", replace
graph export "results/figure_6_right.eps", replace

* ------------------------------------------------------------
* Figure 7
* ------------------------------------------------------------

* open ACS 2009
use finaldata/skillacs.dta, clear

* limit to sample of workers
drop if missing(lwage)

* weighted average in PUMA 
* note: puma does not uniquely identify region across states!
egen wage_avg = wtmean(wage), by(statepuma) weight(earnwt)
egen lwage_avg = wtmean(lwage), by(statepuma) weight(earnwt)

* only keep one observation per PUMA
egen seq = seq(), by(statepuma)
keep if seq == 1
keep state puma statepuma cbsa wage_avg lwage_avg lrentindexpuma rentindexpuma pop2009

* select 5 CBSA
generate lwage_avg_5_35620 = lwage_avg if cbsa==35620
label var lwage_avg_5_35620 "New York-Northern NJ-Long Island"
generate lwage_avg_5_31100 = lwage_avg if cbsa==31100
label var lwage_avg_5_31100 "Los Angeles-Long Beach-Santa Ana"
generate lwage_avg_5_16980 = lwage_avg if cbsa==16980
label var lwage_avg_5_16980 "Chicago-Naperville-Joliet"
generate lwage_avg_5_14460 = lwage_avg if cbsa==14460
label var lwage_avg_5_14460 "Boston-Cambridge-Quincy"
generate lwage_avg_5_19820 = lwage_avg if cbsa==19820
label var lwage_avg_5_19820 "Detroit-Warren-Livonia"

* plot scatter of selected CBSA
#delimit ;
	scatter lwage_avg_* rentindexpuma, 
		mcolor(black black black black black) 
		msymbol(O Oh Dh Th Sh) 
		xtitle("housing price index") 
		ytitle("average log wage")
	scheme(s1color) legend(cols(1) position(2) region(lstyle(none)))
	xsize(7) ysize(3.2) scale(1.1)
	;	
#delimit cr

* save graph
graph export "results/figure_7.pdf", replace
graph export "results/figure_7.eps", replace

* variance decomposition
xtset cbsa
xtsum lwage_avg rentindexpuma if pop2009>100000 & ~missing(pop2009)

* ------------------------------------------------------------
* Section 6.2, eq. (17)
* ------------------------------------------------------------

* open CEX 2011
use finaldata/cex.dta, clear

* generate covariates
generate hprice_wkinc = rentindexcbsa/wkinc if wkinc > 0
generate hprice_wktotexp = rentindexcbsa/wktotexp if wktotexp > 0

* regress expenditure shares on weekly income
reg sheltcq_shr hprice_wkinc [aw=finlwt21] if wkinc>175, vce(robust)
disp "alpha = " _b[_cons]
disp "h_bar = " _b[hprice_wkinc]/(1-_b[_cons])
nlcom _b[hprice_wkinc]/(1-_b[_cons])

* predict expenditure share for low (175) and high (22,127) wage
disp "s_lowage=" _b[_cons]+_b[hprice_wkinc]*1/175
disp "s_hiwage=" _b[_cons]+_b[hprice_wkinc]*1/22127 // limit is alpha

* ------------------------------------------------------------
* Figure 9 left
* ------------------------------------------------------------

* OLS
reg sheltcq_shr hprice_wkinc [aw=finlwt21] if wkinc>175, vce(robust)
predict sheltcq_shr_reghat if e(sample)
sum sheltcq_shr_reghat
sort hprice_wkinc

* local linear regression
lpoly sheltcq_shr hprice_wkinc [aw=finlwt21] if wkinc>175, degree(1) generate(hprice_wkinc_lpoly sheltcq_shr_lpoly) se(se_lpoly) nograph
generate sheltcq_shr_lpoly_lo = sheltcq_shr_lpoly-1.96*se_lpoly
generate sheltcq_shr_lpoly_up = sheltcq_shr_lpoly+1.96*se_lpoly

#delimit ; 
twoway
	rarea sheltcq_shr_lpoly_lo sheltcq_shr_lpoly_up hprice_wkinc_lpoly,
	legend(label(1 "95% confidence bounds"))
	color(gs12)  lwidth(none)
	||
	line sheltcq_shr_lpoly hprice_wkinc_lpoly,
	lpattern(solid) lcolor(black) legend(label(2 "local linear regression"))
	||
	line sheltcq_shr_reghat hprice_wkinc if e(sample),
	lpattern(dash) lcolor(black) legend(label(3 "OLS"))
	, xtitle("houseprice divided by weekly income (p/w)") ytitle("housing expenditure share (s)") 
	xlabel(0(0.002)0.009)
	scheme(s1color) legend(region(lstyle(none))) legend(order(2 1 3))
;
#delimit cr

* save graph
graph export "results/figure_9_left.pdf", replace
graph export "results/figure_9_left.eps", replace

* ------------------------------
* Figure 9 right
* ------------------------------

* open skill data from CPS
use finaldata/skillcps.dta, clear

* sample,  keep only observations
* - identified CBSA 
* - with assigned CBSA housing price
* - cbsa with population > 100000
keep if ~missing(cbsa) & ~missing(rentindexcbsa) & (pop2009>=100000 & ~missing(pop2009))


* define city groups
generate group = .
replace group = 1 if pop2009<=1000000 & pop2009>100000 & ~missing(pop2009)
replace group = 2 if pop2009>2500000 & ~missing(pop2009)
label define group 1 "pop < 1m" 2 "pop > 2.5m"
generate group1 = (group==1) if ~missing(group)
generate group2 = (group==2) if ~missing(group)

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility4 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility4 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility4 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility4 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility4 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility4 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility)") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_9_right.pdf", replace
graph export "results/figure_9_right.eps", replace

* ------------------------------
* Figure 14, Appendix B
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility5 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility5 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility5 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility5 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility5 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility5 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility)") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);

#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_14.pdf", replace
graph export "results/figure_14.eps", replace

* ------------------------------
* Section 6.3
* ------------------------------

* open costofliving data
use finaldata/costliving.dta, clear

* CBSA with population over 100,000
keep if pop2009>=100000 & ~missing(pop2009)

* mean and standard deviation across CBSA
sum price_housing price_grocery price_utilities price_transport price_health lprice_services

* ------------------------------
* Figure 10
* ------------------------------

* open skill data from CPS
use finaldata/skillcps.dta, clear

* sample,  keep only observations
* - identified CBSA 
* - with assigned CBSA housing price
* - cbsa with population > 100000
keep if ~missing(cbsa) & ~missing(rentindexcbsa) & pop2009>=100000 & ~missing(pop2009)

* define city groups
generate group = .
replace group = 1 if pop2009<=1000000 & pop2009>100000 & ~missing(pop2009)
replace group = 2 if pop2009>2500000 & ~missing(pop2009)
label define group 1 "pop < 1m" 2 "pop > 2.5m"
generate group1 = (group==1) if ~missing(group)
generate group2 = (group==2) if ~missing(group)

* ------------------------------
* Figure 10 left
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility6 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility6 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility6 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility6 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility6 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility6 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(1(1)3) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(1(1)3) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility)") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_10_left.pdf", replace
graph export "results/figure_10_left.eps", replace

* ------------------------------------------------------------
* Figure 10 right
* ------------------------------------------------------------

* keep only observations from cbsa with more than 0.1 Mio
keep if (pop2009>=100000 & ~missing(pop2009))

* estimate selective quantile regressions for footer of figure
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	qreg lutility6 lpop2009 [aw=earnwt], q(`quant')
	estimates store skill_q`quantpct'
	predict lutility_q`quantpct' if e(sample), xb
	local slope`quantpct' = string(_b[lpop2009],"%9.3f")
	local se`quantpct' = string(_se[lpop2009],"%9.3f")
	local p`quantpct' = string(ttail(e(df_r), abs(_b[lpop2009]/_se[lpop2009])),"%9.1f")
	if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.005 {
		local star`quantpct' = "***"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.025 {
		local star`quantpct' = "**"
	}
	else if normal(-abs(_b[lpop2009]/_se[lpop2009])) <= 0.05 {
		local star`quantpct' = "*"
	}
	else {
		local star`quantpct' = ""
	}
}

* plot all quantiles
qreg lutility6 lpop2009 [aw=earnwt]
grqreg lutility6 lpop2009 [aw=earnwt], ci save(temp/figure_4_right.dta)
use temp/figure_4_right.dta, clear
#delimit ;
twoway 
	rarea lpop2009_cihi lpop2009_cilo qtile, lpattern(none) color(gs14) legend(label(1 "95% confidence bounds")) 
	||
	line lpop2009 qtile, lpattern(solid) lcolor(black) legend(label(2 "slope coefficient")) 
	, xtitle("skill quantile") ytitle("slope of log population") 
	scheme(s1color) legend(region(lstyle(none))) legend(order(2 1)) legend(rows(1))
	yline(0, lpattern(solid))
	xsize(5.50) ysize(4.3) scale(1)
	note(
		"10th percentile: slope = `slope10'`star10' (`se10')" 
		"90th percentile: slope = `slope90'`star90' (`se90')" 
	);
#delimit cr

* save graph
graph export "results/figure_10_right.pdf", replace
graph export "results/figure_10_right.eps", replace
